#!/bin/sh
#*******************************************************************************
#Licensed Materials - Property of IBM
#(c) Copyright IBM Corporation 2006-2008. All Rights Reserved.
#
#Note to U.S. Government Users Restricted Rights:  
#Use, duplication or disclosure restricted by GSA ADP Schedule 
#Contract with IBM Corp. 
#*******************************************************************************
# Jazz RepoTools Launcher

pwd | grep -q "[[:space:]]"
if [ $? -eq 0 ];
  then /bin/echo -e \
ERROR:  The Jazz Team Server may not be installed in a directory whose name \\n\
contains a space character.  Please relocate the jazz directory and try again.
  exit 1
fi

START_DIR=$(dirname "$0")

# The following four environment variables (*_ABSPATH) are used to point to a
# directory that contains the appropriate JDBC jar file supplied by the database
# vendor.  Users may set these variables; if they are set, the script will
# respect their value.  If they are unset, we look in a directory under
# <JazzInstallDir>/server by default.  (For example, the default location for
# the Oracle JDBC driver is under <JazzInstallDir>/server/oracle).

if [ -z $ORACLE_ABSPATH ] ; then
  ORACLE_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/oracle" ;
fi

if [ -z $SQLSERVER_ABSPATH ] ; then
  SQLSERVER_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/sqlserver" ;
fi

if [ -z $DB2I_ABSPATH ] ; then
  DB2I_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/db2i" ;
fi

if [ -z $DB2Z_ABSPATH ] ; then
  DB2Z_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/db2z" ;
fi

#DEFINE="$DEFINE -Dcom.ibm.team.repotools.rcp.allowInvalidBundles=true"
DEFINE="$DEFINE -Dcom.ibm.team.repository.provision.profile=$START_DIR/provision_profiles"
DEFINE="$DEFINE -Dorg.eclipse.emf.ecore.plugin.EcorePlugin.doNotLoadResourcesPlugin=true"
DEFINE="$DEFINE -Djava.awt.headless=true"
DEFINE="$DEFINE -DORACLE_JDBC=$ORACLE_ABSPATH"
DEFINE="$DEFINE -DSQLSERVER_JDBC=$SQLSERVER_ABSPATH"
DEFINE="$DEFINE -DDB2I_JDBC=$DB2I_ABSPATH"
DEFINE="$DEFINE -DDB2Z_JDBC=$DB2Z_ABSPATH"
    
JAVA="$START_DIR/linux/ibm-java2-i386-50/jre/bin/java"
LAUNCHER=org.eclipse.equinox.launcher_1.0.1.R33x_v20080118.jar         
JAR="$START_DIR/../repotools/eclipse/plugins/$LAUNCHER"
APPLICATION=com.ibm.team.repotools.rcp.repotools_application
    
$JAVA -Xmx512M $DEFINE -jar $JAR -application $APPLICATION $* 
